@@ -30,6 +30,7 @@ from .._impl import (
     api_SerializableError as SerializableError,
     api_SeriesArchetypeRid as SeriesArchetypeRid,
     api_SeriesDataType as SeriesDataType,
+    api_SetOperator as SetOperator,
     api_SuccessResult as SuccessResult,
     api_TagName as TagName,
     api_TagValue as TagValue,
@@ -70,6 +71,7 @@ __all__ = [
     'SerializableError',
     'SeriesArchetypeRid',
     'SeriesDataType',
+    'SetOperator',
     'SuccessResult',
     'TagName',
     'TagValue',
