@@ -24,6 +24,7 @@ from .._impl import (
     event_GetEvents as GetEvents,
     event_HistogramFilterQuery as HistogramFilterQuery,
     event_HistogramFilterQueryVisitor as HistogramFilterQueryVisitor,
+    event_ListPropertiesAndLabelsRequest as ListPropertiesAndLabelsRequest,
     event_ProcedureEventOrigin as ProcedureEventOrigin,
     event_SearchEventOriginType as SearchEventOriginType,
     event_SearchEventsRequest as SearchEventsRequest,
@@ -63,6 +64,7 @@ __all__ = [
     'GetEvents',
     'HistogramFilterQuery',
     'HistogramFilterQueryVisitor',
+    'ListPropertiesAndLabelsRequest',
     'ProcedureEventOrigin',
     'SearchEventOriginType',
     'SearchEventsRequest',
